朗读者 (豆瓣)
Description: 朗读者电影简介和剧情介绍,朗读者影评、图片、预告片、影讯、论坛、在线购票
Keywords: 朗读者,The Reader,朗读者影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.242豆瓣电影Top250

# 朗读者 The Reader (2008)

导演: 史蒂芬·戴德利
编剧: 戴维·黑尔 / 本哈德·施林克
主演: 凯特·温丝莱特 / 大卫·克劳斯 / 拉尔夫·费因斯 / 詹妮特·海因 / 苏珊娜·洛塔尔 / Alissa Wilms / 弗罗里安·巴西奥罗麦 / 弗里德里克·贝希特 / 马蒂亚斯·哈比希 / Frieder Venus / Marie-Anne Fliegel / Hendrik Arnst / Rainer Sellien / 托尔斯滕·米凯利斯 / Moritz Grove
类型: 剧情 / 爱情
制片国家/地区: 美国 / 德国
语言: 英语 / 德语 / 希腊语 / 拉丁语
上映日期: 2008-12-10(纽约首映) / 2009-01-30(美国) / 2009-02-26(德国)
片长: 124 分钟
又名: 为爱朗读(台) / 读爱(港) / 生死朗读
IMDb: tt0976051
豆瓣评分
引用
8.6
438376人评价
5星
42.7%
4星
45.6%
3星
11.0%
2星
0.6%
1星
0.1%
好于 97% 爱情片
好于 96% 剧情片
想看 看过
评价:
推荐

## 朗读者的剧情简介 · · · · · ·

15岁的少年米夏·伯格（大卫·克劳斯 David Kross 饰）偶遇36岁的中年神秘女列车售票员汉娜（凯特·温丝莱特 Kate Winslet 饰），后来两个发展出一段秘密的情人关系。汉娜最喜欢躺在米夏怀里听米夏为他读书，她总是沉浸在那朗朗的读书声中。年轻的米夏沉溺于这种关系不能自拔的同时，却发现他自己根本不了解汉娜。忽然有一天，这个神秘女人不告而别，米夏在短暂的迷惑和悲伤之后，开始了新的生活。
二战虽然结束了，但德国对于纳粹战犯的审判还在继续。成为法律学校的实习生的米夏，在一次旁听对纳粹战犯的审判过程中，竟然发现一个熟悉的身影。虽然已经事隔8年，但米夏还是一眼便认出那就是消失8年的汉娜。而这一次，她坐上了纳粹战犯审判法庭的被告席，这个神秘女人的往事在案件的审理过程中逐渐清晰。然而，米夏却发现了一个汉娜宁愿搭上性命也要隐藏秘密。
汉娜最终被判终身监... (展开全部) 15岁的少年米夏·伯格（大卫·克劳斯 David Kross 饰）偶遇36岁的中年神秘女列车售票员汉娜（凯特·温丝莱特 Kate Winslet 饰），后来两个发展出一段秘密的情人关系。汉娜最喜欢躺在米夏怀里听米夏为他读书，她总是沉浸在那朗朗的读书声中。年轻的米夏沉溺于这种关系不能自拔的同时，却发现他自己根本不了解汉娜。忽然有一天，这个神秘女人不告而别，米夏在短暂的迷惑和悲伤之后，开始了新的生活。
二战虽然结束了，但德国对于纳粹战犯的审判还在继续。成为法律学校的实习生的米夏，在一次旁听对纳粹战犯的审判过程中，竟然发现一个熟悉的身影。虽然已经事隔8年，但米夏还是一眼便认出那就是消失8年的汉娜。而这一次，她坐上了纳粹战犯审判法庭的被告席，这个神秘女人的往事在案件的审理过程中逐渐清晰。然而，米夏却发现了一个汉娜宁愿搭上性命也要隐藏秘密。
汉娜最终被判终身监禁，而此时米夏（拉尔夫·费因斯 Ralph Fiennes 饰）与汉娜的故事还在继续……
在2009年初的第81届奥斯卡上，该片共获包括最佳女主角在内的5项提名，最终温丝莱特凭借该片折冠当年奥斯卡影后。 ©豆瓣

## 朗读者的演职员 · · · · · · ( 全部 45 )

- 史蒂芬·戴德利 导演
- 凯特·温丝莱特 饰 Hanna Schmitz
- 大卫·克劳斯 饰 Young Michael Berg
- 拉尔夫·费因斯 饰 Michael Berg
- 詹妮特·海因 饰 Brigitte
- 苏珊娜·洛塔尔 饰 Carla Berg

## 朗读者的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片1023 · 添加 )

## 朗读者的获奖情况 · · · · · · ( 全部 )

- 第81届奥斯卡金像奖
- 最佳影片(提名)
- 雷德芒德·莫瑞斯 / 西德尼·波拉克 / 安东尼·明格拉 / 唐娜·吉格里奥蒂

- 第66届金球奖
- 电影类 最佳剧情片(提名)

- 第22届欧洲电影奖
- 最佳影片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  爱在日落黄昏时

  恋恋笔记本

  甜蜜蜜

  英国病人

  重庆森林

  花样年华

  乱世佳人

  天使爱美丽

  泰坦尼克号

我要写短评

## 朗读者的短评 · · · · · · ( 全部 82826 条 )

热门 / 最新 / 好友

### 4090 有用 暖鱼 看过 2009-06-28 01:06:26

人因羞耻感而保有秘密，却又因秘密而困锁，但又因坚守秘密，留有一份尊严。难以言述的电影。

### 2296 有用 思阳 看过 2009-02-22 13:40:09

终于有从另一个角度看纳粹的电影了。人性的愚笨，执着，甚至荒谬，却又是那样的自然，值得同情，甚至是值得尊敬的。这是今年奥斯卡最佳电影提名里面我认为最有深度和内涵的片子。Winslet的表演也相当棒，把一个低层劳动妇女的善良与粗犷刻画得入木三分。

### 1508 有用 莫呼洛迦-屁股上的青春在歌唱 看过 2009-03-01 20:48:05

要不是那天的呕吐，也就不会有这么一段爱情。

### 1068 有用 苏更生 看过 2009-03-18 13:46:04

上、下部跳tone太厉害。影片末尾真是累赘至极。 有一个镜头很美，汉娜离开后，麦克在湖边，他脱了衣服，把脚放到湖中，幽幽的湖水裹住他苍白的脚。这个镜头很独特。(为什么独特我说不上来，我只能感觉到。应该要把抽象的感觉化为理论的东西，我仔细想想。) 还有，汉娜到底有没有罪？虽然良知薄弱，但片中教授说到，主导我们生活的是法律，法律要的是证据。 道德虽广，但毕竟抽象；法律狭隘，但约束力强。 在... 上、下部跳tone太厉害。影片末尾真是累赘至极。 有一个镜头很美，汉娜离开后，麦克在湖边，他脱了衣服，把脚放到湖中，幽幽的湖水裹住他苍白的脚。这个镜头很独特。(为什么独特我说不上来，我只能感觉到。应该要把抽象的感觉化为理论的东西，我仔细想想。) 还有，汉娜到底有没有罪？虽然良知薄弱，但片中教授说到，主导我们生活的是法律，法律要的是证据。 道德虽广，但毕竟抽象；法律狭隘，但约束力强。 在当时法律来看（纳粹时期），汉娜没罪，她遵守规定，以看守犯人为责任，但是泯灭良知。 (展开)

### 1915 有用 眠去 看过 2009-01-20 12:54:03

“只有一件事可以让灵魂完整，那就是爱！”男孩流着泪的脸经过隧道的阴影，变成了男人，但对她的爱从未消逝，从十五岁开始，一直到她死。甚至他死。

> 更多短评 82826条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 朗读者的影评 · · · · · · ( 全部 3417 条 )

热门 / 最新 / 好友
picnic 2009-01-06 05:00:01

## 羞耻与谎言

如果十五岁的你热恋上中年独居女邻居，与她的恋情即便在你们分手后还深深影响着你。然而八年后情伤未愈的你突然发现她竟是一名刽子手，而你的证词能使她免遭终生监禁，你，该怎样做？ 这是The Reader呈现给我们的难题。 对Holocaust的控诉、描述和反思，电影中我们已经拥有了... (展开)
6202 397 596回应 收起
matchbox 2009-01-30 15:06:23

## 读完原著之后的一些碎念

看过电影之后，读了[朗读者]原著小说（选择的是姚仲珍的译本）。Stephen Daldry的这部电影，让我在目及狱中朗读的段落时难以抑制落泪。而小说，尽管开读时并不满意其译文，但是第一人称的角度让我目睹了人物内心所有的挣扎、羞耻、麻木和愧歉。之前看完电影之后的感叹与不解，... (展开)
1802 61 305回应 收起
sabretooth 2009-03-03 19:06:03

## 十六岁那年的夏天

虽然标题这么写了，但如果这仅仅是一出十六岁夏天的故事，那么Oscar的挑剔的评审们也不会把它列入最佳影片的角逐名单。 当初我在一所美国大学学习日本历史的时候，一个韩国助教这样问我们，亚洲战场的元凶到底是谁：是天皇还是政府，是国民还是军队，亦或是，如日本右翼认为的... (展开)
1704 44 188回应 收起
柏邦妮 2012-11-07 02:32:55

## 不远离，不原谅，不遗忘

不远离，不原谅，不遗忘 深夜又看了一遍《朗读者》，内心惶惶。很想写点什么，但是已经很久没写字了，有点怕。我没有揣好答案就提笔了。因为我想，有时，写下来，也是一种提问。 从什么地方说起呢？从我没有想象过，一个文盲女人是什么样子开始吧。当她出现在电影里，成为一... (展开)
1575 38 123回应 收起
艾小柯 2009-10-22 13:04:11

## 朔方的雪

魯迅在《雪》中写到：“朔方的雪……，却永远如粉，如沙，他们绝不粘连……在晴天之下，旋风乎来，便蓬勃的奋飞，在日光中熠熠地生光，如包藏火焰的大雾，旋转而且升腾，弥漫太空，使太空旋转而且升腾地闪烁。”结尾，鲁迅总结这样凄清苍茫的景色时说，“那是孤独的雪，是死掉... (展开)
398 6 52回应 收起
图宾根木匠 2009-06-15 10:25:06

## 《生死朗读》：现代性与大屠杀

这篇影评可能有剧透

打动我的不仅仅是凯特·温丝莱特的裸体，更多的是那位风烛残年的汉娜·施密茨悬梁自尽的身影——这位泰坦尼克号上的老肉丝曾经在成就了一段世纪浪漫之后把她的“海洋之心”还给了大海，而这一次，老肉丝缓慢、滞重、无依无靠，她把生命还给了世界，而导演甚至不忍心让我们看到... (展开)
511 12 54回应 收起
qzz345 2009-03-08 22:24:32

## 罪与罚

大约是1999年的夏天，我那时正在北京一所法学院做大二学生。一天晚上，学校4号阶梯教室有一个日本青年学者来做讲座，讲的课题是战后日本司法改革。演讲完毕后，照例是讨论时间。不知道怎么的就扯到了日本参拜靖国神社，否认战争罪行，不肯谢罪的问题上了。一时间学生群情激奋，... (展开)
451 11 78回应 收起
funny_vee 2009-02-14 22:44:15

## 杀人犯在我们当中

《朗读者》作为爱情片，很赚人眼泪，可惜导演对人性和纳粹历史的反省，却做了大量的减法。 比如： 二战结束后的15年中，西德对纳粹历史的态度以沉默与回避为主。因为纳粹政权有关的人数太多，从军人数1500万……光妇女就有230多万是法西斯团体成员，6千多名女青年是集中营的看... (展开)
327 36 80回应 收起
仙谷雾隐 2009-02-21 23:53:07

## 影片《The Reader》全解读——Warning！超级大剧透，慎入

这篇影评可能有剧透

影片《The Reader》全解读 By：JuLeo 注意！！！《朗读者》在美国的分级是USA:R，属于限制级影片，17岁以下必须由父母或者监护陪伴才能观看!(美国电影分级制度http://www.southcn.com/ent/zhuanti/fenji/news/200303100147.htm） 《The Reader》并不是一部平铺直叙... (展开)
240 5 38回应 收起

> 更多影评 3417篇

添加新讨论

## 讨论区 · · · · · ·

哪里可以播呀 | 来自brandon30983 | 13 回应 | 2022-11-23 10:49:09
汉娜你哪怕多等等 | 来自阿妍的第三个号 | 1 回应 | 2022-11-20 01:20:05
请问有《朗读者》网盘资源吗？ | 来自Farewell. | 17 回应 | 2022-11-19 20:52:40
这就是一部三级片！ | 来自少年派奇幻漂流 | 24 回应 | 2022-11-17 14:52:18
这部电影想表达的是什么啊？ | 来自陈心如水 | 3 回应 | 2022-11-15 17:55:39

> 去这部影片的讨论区（全部754条）

## 关于《朗读者》的问题 · · · · · · ( 全部48个 )

- 汉娜为什么选择自杀？ 11人回答
- 一个人一旦参与到诉讼程序，怎么可能掩盖自己是个文盲？ 9人回答

> 全部48个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【内牛满面】 (影志)
- 独立女性必看电影 (aristos)
- 【坚强的女性】 (影志)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  刚刚 想看
- 豆友O4WfE_FJiI
  1分钟前 看过
- 孙一
  6分钟前 想看

622517人看过 / 280719人想看

订阅朗读者的评论:
feed: rss 2.0